---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: bug, needs triage
assignees: chicolucio

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Import '...'
2.
3.


**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Specification**
- pH-diagrams version
- Python version
- platform

**Additional context**
Add any other context about the problem here.
